aboutsummaryrefslogtreecommitdiff
path: root/src/backend/commands/command.c
diff options
context:
space:
mode:
authorTom Lane <tgl@sss.pgh.pa.us>2002-03-22 21:34:44 +0000
committerTom Lane <tgl@sss.pgh.pa.us>2002-03-22 21:34:44 +0000
commita25b94c080a644a66983bbcf82a4e358aa47b7df (patch)
treec95562da0fe5569e9cd3ee204718912392fbbb0c /src/backend/commands/command.c
parent48c916490179e4a1db93e0924a72c3e4f1f00e55 (diff)
downloadpostgresql-a25b94c080a644a66983bbcf82a4e358aa47b7df.tar.gz
postgresql-a25b94c080a644a66983bbcf82a4e358aa47b7df.zip
Create the pg_namespace system catalog. Doesn't do much yet, but it's
there and CREATE SCHEMA will make entries in it...
Diffstat (limited to 'src/backend/commands/command.c')
-rw-r--r--src/backend/commands/command.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/backend/commands/command.c b/src/backend/commands/command.c
index b9741e0f3a5..af9e76e2791 100644
--- a/src/backend/commands/command.c
+++ b/src/backend/commands/command.c
@@ -8,7 +8,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.164 2002/03/22 02:56:31 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.165 2002/03/22 21:34:44 tgl Exp $
*
* NOTES
* The PerformAddAttribute() code, like most of the relation
@@ -28,6 +28,7 @@
#include "catalog/indexing.h"
#include "catalog/pg_attrdef.h"
#include "catalog/pg_index.h"
+#include "catalog/pg_namespace.h"
#include "catalog/pg_opclass.h"
#include "catalog/pg_relcheck.h"
#include "catalog/pg_type.h"
@@ -2008,12 +2009,10 @@ CreateSchemaCommand(CreateSchemaStmt *stmt)
owner_name, authId);
}
- /* FIXME FENN: Create the schema here */
- (void) schemaName; /* suppress compiler warning for now... */
+ /* Create the schema's namespace */
+ NamespaceCreate(schemaName);
- /*
- * Let commands in the schema-element-list know about the schema
- */
+ /* Let commands in the schema-element-list know about the schema */
CommandCounterIncrement();
/*